==> qtjambi-qt3danimation-jre8-5.15.3-sources.jar: io/qt/qt3d/animation/QLerpClipBlend.java <==
package io.qt.qt3d.animation;


/**
 * <p>Performs a linear interpolation of two animation clips based on a normalized factor</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qt3danimation-qlerpclipblend.html">Qt3DAnimation::QLerpClipBlend</a></p>
 */
public class QLerpClipBlend extends io.qt.qt3d.animation.QAbstractClipBlendNode
{
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QLerpClipBlend.class);
    

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3danimation-qlerpclipblend.html#blendFactor-prop">Qt3DAnimation::QLerpClipBlend::blendFactorChanged(float)</a></p>
     */
    @io.qt.QtPropertyNotify(name="blendFactor")
    public final Signal1<@io.qt.QtPrimitiveType Float> blendFactorChanged = new Signal1<>();

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3danimation-qlerpclipblend.html#endClip-prop">Qt3DAnimation::QLerpClipBlend::endClipChanged(Qt3DAnimation::QAbstractClipBlendNode*)</a></p>
     */
    @io.qt.QtPropertyNotify(name="endClip")
    public final Signal1<io.qt.qt3d.animation.QAbstractClipBlendNode> endClipChanged = new Signal1<>();

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3danimation-qlerpclipblend.html#startClip-prop">Qt3DAnimation::QLerpClipBlend::startClipChanged(Qt3DAnimation::QAbstractClipBlendNode*)</a></p>
     */
    @io.qt.QtPropertyNotify(name="startClip")
    public final Signal1<io.qt.qt3d.animation.QAbstractClipBlendNode> startClipChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QLerpClipBlend(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QLerpClipBlend() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    @SuppressWarnings({"exports"})
    public QLerpClipBlend(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QLerpClipBlend instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3danimation-qlerpclipblend.html#blendFactor-prop">Qt3DAnimation::QLerpClipBlend::blendFactor()const</a></p>
     */
    @io.qt.QtPropertyReader(name="blendFactor")
    @io.qt.QtUninvokable
    public final float blendFactor(){
        return blendFactor_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native float blendFactor_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3danimation-qlerpclipblend.html#endClip-prop">Qt3DAnimation::QLerpClipBlend::endClip()const</a></p>
     */
    @io.qt.QtPropertyReader(name="endClip")
    @io.qt.QtUninvokable
    public final io.qt.qt3d.animation.QAbstractClipBlendNode endClip(){
        return endClip_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.qt3d.animation.QAbstractClipBlendNode endClip_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3danimation-qlerpclipblend.html#blendFactor-prop">Qt3DAnimation::QLerpClipBlend::setBlendFactor(float)</a></p>
     */
    @io.qt.QtPropertyWriter(name="blendFactor")
    public final void setBlendFactor(float blendFactor){
        setBlendFactor_native_float(QtJambi_LibraryUtilities.internal.nativeId(this), blendFactor);
    }
    
    private native void setBlendFactor_native_float(long __this__nativeId, float blendFactor);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3danimation-qlerpclipblend.html#endClip-prop">Qt3DAnimation::QLerpClipBlend::setEndClip(Qt3DAnimation::QAbstractClipBlendNode*)</a></p>
     */
    @io.qt.QtPropertyWriter(name="endClip")
    public final void setEndClip(io.qt.qt3d.animation.QAbstractClipBlendNode endClip){
        setEndClip_native_Qt3DAnimation_QAbstractClipBlendNode_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(endClip));
    }
    
    private native void setEndClip_native_Qt3DAnimation_QAbstractClipBlendNode_ptr(long __this__nativeId, long endClip);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3danimation-qlerpclipblend.html#startClip-prop">Qt3DAnimation::QLerpClipBlend::setStartClip(Qt3DAnimation::QAbstractClipBlendNode*)</a></p>
     */
    @io.qt.QtPropertyWriter(name="startClip")
    public final void setStartClip(io.qt.qt3d.animation.QAbstractClipBlendNode startClip){
        setStartClip_native_Qt3DAnimation_QAbstractClipBlendNode_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(startClip));
    }
    
    private native void setStartClip_native_Qt3DAnimation_QAbstractClipBlendNode_ptr(long __this__nativeId, long startClip);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3danimation-qlerpclipblend.html#startClip-prop">Qt3DAnimation::QLerpClipBlend::startClip()const</a></p>
     */
    @io.qt.QtPropertyReader(name="startClip")
    @io.qt.QtUninvokable
    public final io.qt.qt3d.animation.QAbstractClipBlendNode startClip(){
        return startClip_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.qt3d.animation.QAbstractClipBlendNode startClip_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QLerpClipBlend(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QLerpClipBlend(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QLerpClipBlend instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-qt3danimation-jre8-6.3.0-sources.jar: io/qt/qt3d/animation/QLerpClipBlend.java <==
package io.qt.qt3d.animation;


/**
 * <p>Performs a linear interpolation of two animation clips based on a normalized factor</p>
 * <p>Java wrapper for Qt class <a href="https://doc.qt.io/qt/qt3danimation-qlerpclipblend.html">Qt3DAnimation::QLerpClipBlend</a></p>
 */
public class QLerpClipBlend extends io.qt.qt3d.animation.QAbstractClipBlendNode
{
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QLerpClipBlend.class);
    

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3danimation-qlerpclipblend.html#blendFactor-prop">Qt3DAnimation::QLerpClipBlend::blendFactorChanged(float)</a></p>
     */
    @io.qt.QtPropertyNotify(name="blendFactor")
    public final Signal1<@io.qt.QtPrimitiveType Float> blendFactorChanged = new Signal1<>();

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3danimation-qlerpclipblend.html#endClip-prop">Qt3DAnimation::QLerpClipBlend::endClipChanged(Qt3DAnimation::QAbstractClipBlendNode*)</a></p>
     */
    @io.qt.QtPropertyNotify(name="endClip")
    public final Signal1<io.qt.qt3d.animation.QAbstractClipBlendNode> endClipChanged = new Signal1<>();

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3danimation-qlerpclipblend.html#startClip-prop">Qt3DAnimation::QLerpClipBlend::startClipChanged(Qt3DAnimation::QAbstractClipBlendNode*)</a></p>
     */
    @io.qt.QtPropertyNotify(name="startClip")
    public final Signal1<io.qt.qt3d.animation.QAbstractClipBlendNode> startClipChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QLerpClipBlend(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QLerpClipBlend() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    @SuppressWarnings({"exports"})
    public QLerpClipBlend(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QLerpClipBlend instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3danimation-qlerpclipblend.html#blendFactor-prop">Qt3DAnimation::QLerpClipBlend::blendFactor()const</a></p>
     */
    @io.qt.QtPropertyReader(name="blendFactor")
    @io.qt.QtUninvokable
    public final float blendFactor(){
        return blendFactor_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native float blendFactor_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3danimation-qlerpclipblend.html#endClip-prop">Qt3DAnimation::QLerpClipBlend::endClip()const</a></p>
     */
    @io.qt.QtPropertyReader(name="endClip")
    @io.qt.QtUninvokable
    public final io.qt.qt3d.animation.QAbstractClipBlendNode endClip(){
        return endClip_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.qt3d.animation.QAbstractClipBlendNode endClip_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3danimation-qlerpclipblend.html#blendFactor-prop">Qt3DAnimation::QLerpClipBlend::setBlendFactor(float)</a></p>
     */
    @io.qt.QtPropertyWriter(name="blendFactor")
    public final void setBlendFactor(float blendFactor){
        setBlendFactor_native_float(QtJambi_LibraryUtilities.internal.nativeId(this), blendFactor);
    }
    
    private native void setBlendFactor_native_float(long __this__nativeId, float blendFactor);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3danimation-qlerpclipblend.html#endClip-prop">Qt3DAnimation::QLerpClipBlend::setEndClip(Qt3DAnimation::QAbstractClipBlendNode*)</a></p>
     */
    @io.qt.QtPropertyWriter(name="endClip")
    public final void setEndClip(io.qt.qt3d.animation.QAbstractClipBlendNode endClip){
        setEndClip_native_Qt3DAnimation_QAbstractClipBlendNode_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(endClip));
    }
    
    private native void setEndClip_native_Qt3DAnimation_QAbstractClipBlendNode_ptr(long __this__nativeId, long endClip);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3danimation-qlerpclipblend.html#startClip-prop">Qt3DAnimation::QLerpClipBlend::setStartClip(Qt3DAnimation::QAbstractClipBlendNode*)</a></p>
     */
    @io.qt.QtPropertyWriter(name="startClip")
    public final void setStartClip(io.qt.qt3d.animation.QAbstractClipBlendNode startClip){
        setStartClip_native_Qt3DAnimation_QAbstractClipBlendNode_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(startClip));
    }
    
    private native void setStartClip_native_Qt3DAnimation_QAbstractClipBlendNode_ptr(long __this__nativeId, long startClip);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3danimation-qlerpclipblend.html#startClip-prop">Qt3DAnimation::QLerpClipBlend::startClip()const</a></p>
     */
    @io.qt.QtPropertyReader(name="startClip")
    @io.qt.QtUninvokable
    public final io.qt.qt3d.animation.QAbstractClipBlendNode startClip(){
        return startClip_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.qt3d.animation.QAbstractClipBlendNode startClip_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QLerpClipBlend(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QLerpClipBlend(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QLerpClipBlend instance, QDeclarativeConstructor constructor);
    
}
